==> kubernetes-model-core-6.13.5-sources.jar: io/fabric8/kubernetes/api/model/NodeRuntimeHandlerFeaturesFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NodeRuntimeHandlerFeaturesFluent<A extends NodeRuntimeHandlerFeaturesFluent<A>> extends BaseFluent<A>{
  public NodeRuntimeHandlerFeaturesFluent() {
  }
  
  public NodeRuntimeHandlerFeaturesFluent(NodeRuntimeHandlerFeatures instance) {
    this.copyInstance(instance);
  }
  private Boolean recursiveReadOnlyMounts;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NodeRuntimeHandlerFeatures instance) {
    instance = (instance != null ? instance : new NodeRuntimeHandlerFeatures());
    if (instance != null) {
          this.withRecursiveReadOnlyMounts(instance.getRecursiveReadOnlyMounts());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Boolean getRecursiveReadOnlyMounts() {
    return this.recursiveReadOnlyMounts;
  }
  
  public A withRecursiveReadOnlyMounts(Boolean recursiveReadOnlyMounts) {
    this.recursiveReadOnlyMounts = recursiveReadOnlyMounts;
    return (A) this;
  }
  
  public boolean hasRecursiveReadOnlyMounts() {
    return this.recursiveReadOnlyMounts != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeRuntimeHandlerFeaturesFluent that = (NodeRuntimeHandlerFeaturesFluent) o;
    if (!java.util.Objects.equals(recursiveReadOnlyMounts, that.recursiveReadOnlyMounts)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(recursiveReadOnlyMounts,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (recursiveReadOnlyMounts != null) { sb.append("recursiveReadOnlyMounts:"); sb.append(recursiveReadOnlyMounts + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withRecursiveReadOnlyMounts() {
    return withRecursiveReadOnlyMounts(true);
  }
  

}

==> kubernetes-model-core-7.1.0-sources.jar: io/fabric8/kubernetes/api/model/NodeRuntimeHandlerFeaturesFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class NodeRuntimeHandlerFeaturesFluent<A extends NodeRuntimeHandlerFeaturesFluent<A>> extends BaseFluent<A>{
  public NodeRuntimeHandlerFeaturesFluent() {
  }
  
  public NodeRuntimeHandlerFeaturesFluent(NodeRuntimeHandlerFeatures instance) {
    this.copyInstance(instance);
  }
  private Boolean recursiveReadOnlyMounts;
  private Boolean userNamespaces;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(NodeRuntimeHandlerFeatures instance) {
    instance = (instance != null ? instance : new NodeRuntimeHandlerFeatures());
    if (instance != null) {
          this.withRecursiveReadOnlyMounts(instance.getRecursiveReadOnlyMounts());
          this.withUserNamespaces(instance.getUserNamespaces());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public Boolean getRecursiveReadOnlyMounts() {
    return this.recursiveReadOnlyMounts;
  }
  
  public A withRecursiveReadOnlyMounts(Boolean recursiveReadOnlyMounts) {
    this.recursiveReadOnlyMounts = recursiveReadOnlyMounts;
    return (A) this;
  }
  
  public boolean hasRecursiveReadOnlyMounts() {
    return this.recursiveReadOnlyMounts != null;
  }
  
  public Boolean getUserNamespaces() {
    return this.userNamespaces;
  }
  
  public A withUserNamespaces(Boolean userNamespaces) {
    this.userNamespaces = userNamespaces;
    return (A) this;
  }
  
  public boolean hasUserNamespaces() {
    return this.userNamespaces != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeRuntimeHandlerFeaturesFluent that = (NodeRuntimeHandlerFeaturesFluent) o;
    if (!java.util.Objects.equals(recursiveReadOnlyMounts, that.recursiveReadOnlyMounts)) return false;
    if (!java.util.Objects.equals(userNamespaces, that.userNamespaces)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(recursiveReadOnlyMounts,  userNamespaces,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (recursiveReadOnlyMounts != null) { sb.append("recursiveReadOnlyMounts:"); sb.append(recursiveReadOnlyMounts + ","); }
    if (userNamespaces != null) { sb.append("userNamespaces:"); sb.append(userNamespaces + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withRecursiveReadOnlyMounts() {
    return withRecursiveReadOnlyMounts(true);
  }
  
  public A withUserNamespaces() {
    return withUserNamespaces(true);
  }
  

}
